@@ -104,7 +104,7 @@ def display_clip_menu(y, event, frame):
         movemodes.select_blank_range(track, pressed_clip)
 
     global _popover_clip_data
-    _popover_clip_data = (pressed_clip, track,  event.x)
+    _popover_clip_data = (pressed_clip, track, event.x)
             
     if track.type == appconsts.VIDEO:
         if not_multi_selection == True:
@@ -130,6 +130,8 @@ def _clip_popover_menu_item_activated(action, variant, data):
     clip, track, x = _popover_clip_data
     handler = POPUP_HANDLERS[item_id]
     handler_data = (clip, track, item_id, item_data)
+    if item_id == "set_master":
+        handler_data = (clip, track, item_id, x)
     handler(handler_data)
 
 def compositor_menu_item_activated(action, variant, action_id):
