@@ -355,7 +355,7 @@ class AbstractContainerActionObject:
 
         return rendered_clip
 
-    def set_video_endoding(self, clip, callback=None):
+    def set_video_endoding(self, clip, callback=None, show_render_buttons=False):
         self.external_encoding_callback = callback
         current_profile_index = mltprofiles.get_profile_index_for_profile(current_sequence().profile)
         # These need to re-initialized always when using this module.
@@ -367,27 +367,51 @@ class AbstractContainerActionObject:
             self.container_data.render_data = toolsencoding.create_container_clip_default_render_data_object(current_sequence().profile)
             
         encoding_panel = toolsencoding.get_encoding_panel(self.container_data.render_data, True)
+        if show_render_buttons == True:
+            render_combo = Gtk.ComboBoxText()
+            render_combo.append_text(_("Render Full Media"))
+            render_combo.append_text(_("Render Clip Length"))
+            render_combo.set_active(0)
 
-        align = dialogutils.get_default_alignment(encoding_panel)
+        vbox = Gtk.VBox()
+        if show_render_buttons == True:
+            vbox.pack_start(render_combo, False, False, 0)
+        vbox.pack_start(encoding_panel, False, False, 0)
         
-        dialog = Gtk.Dialog(_("Container Clip Render Settings"),
+        align = dialogutils.get_default_alignment(vbox)
+
+        if show_render_buttons == True:
+            title = _("Container/Generator Clip Render")
+            ok_text =  _("Render")
+        else:
+            title = _("Set Render Encoding Settings")
+            ok_text =  _("Set Encoding")
+                        
+        dialog = Gtk.Dialog(title,
                             gui.editor_window.window,
                             Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
                             (_("Cancel"), Gtk.ResponseType.REJECT,
-                             _("Set Encoding"), Gtk.ResponseType.ACCEPT))
+                             ok_text, Gtk.ResponseType.ACCEPT))
         dialog.vbox.pack_start(align, True, True, 0)
         dialogutils.set_outer_margins(dialog.vbox)
         dialog.set_resizable(False)
-
         dialog.connect('response', self.encode_settings_callback)
+                    
+        if show_render_buttons == True:
+            self.render_combo = render_combo
+        else:
+            self.render_combo = None
         dialog.show_all()
 
     def encode_settings_callback(self, dialog, response_id):
         if response_id == Gtk.ResponseType.ACCEPT:
             self.container_data.render_data = toolsencoding.get_render_data_for_current_selections()
             if self.external_encoding_callback != None:
-                self.external_encoding_callback(self.container_data.render_data)
-
+                if self.render_combo == None:
+                    self.external_encoding_callback(self.container_data.render_data)
+                else:
+                    self.external_encoding_callback(self.render_combo)
+                    
         dialog.destroy()
         
     def clone_clip(self, old_clip):
@@ -612,7 +636,10 @@ class FluxityContainerActions(AbstractContainerActionObject):
             script_file = open(self.container_data.program)
             user_script = script_file.read()
             profile_file_path = mltprofiles.get_profile_file_path(current_sequence().profile.description())
-            fctx = fluxity.render_preview_frame(user_script, script_file, 0, None, profile_file_path)
+            if self.container_data.unrendered_length == None:
+                self.container_data.unrendered_length = 200
+
+            fctx = fluxity.render_preview_frame(user_script, script_file, 0, self.container_data.unrendered_length, None, profile_file_path)
          
             if fctx.error == None:
                 data_json = fctx.get_script_data()
@@ -633,7 +660,7 @@ class FluxityContainerActions(AbstractContainerActionObject):
         frame = self.container_data.unrendered_length // 2
         screenshot_file = self.get_container_thumbnail_path()
         
-        fctx = fluxity.render_preview_frame(user_script, script_file, frame, None, profile_file_path)
+        fctx = fluxity.render_preview_frame(user_script, script_file, frame, self.container_data.unrendered_length, None, profile_file_path)
         fctx.priv_context.frame_surface.write_to_png(screenshot_file)
         cr, surface = _create_image_surface(screenshot_file)
         return (screenshot_file, surface)
@@ -655,7 +682,8 @@ class FluxityContainerActions(AbstractContainerActionObject):
         
         self.render_range_in = range_in
         self.render_range_out = range_out
- 
+        generator_length = self.container_data.unrendered_length
+
         fluxityheadless.clear_flag_files(self.parent_folder, self.get_container_program_id())
     
         # We need data to be available for render process, 
@@ -677,6 +705,7 @@ class FluxityContainerActions(AbstractContainerActionObject):
         args = ("session_id:" + self.get_container_program_id(),
                 "parent_folder:" + self.parent_folder,
                 "script:" + str(self.container_data.program),
+                "generator_length:" + str(generator_length),
                 "range_in:" + str(range_in),
                 "range_out:"+ str(range_out),
                 "profile_desc:" + PROJECT().profile.description().replace(" ", "_"))  # Here we have our own string space handling, maybe change later..
@@ -799,7 +828,7 @@ class FluxityContainerActions(AbstractContainerActionObject):
         script_file = open(self.container_data.program)
         user_script = script_file.read()
         profile_file_path = mltprofiles.get_profile_file_path(current_sequence().profile.description())
-        
+
         self.container_data.render_data = toolsencoding.create_container_clip_default_render_data_object(current_sequence().profile)
         self.container_data.render_data.do_video_render = False 
         
@@ -807,7 +836,7 @@ class FluxityContainerActions(AbstractContainerActionObject):
         if not os.path.exists(out_folder):
             os.mkdir(out_folder)
 
-        fctx = fluxity.render_preview_frame(user_script, script_file, preview_frame, out_folder, profile_file_path, editors_data_json)
+        fctx = fluxity.render_preview_frame(user_script, script_file, preview_frame, self.container_data.unrendered_length, out_folder, profile_file_path, editors_data_json)
         if fctx.error != None:
             error_callback(fctx.error)
             return
