@@ -589,6 +589,8 @@ def _handle_configurable_global_events(event):
         if gui.media_list_view.widget.has_focus() or gui.media_list_view.widget.get_focus_child() != None: 
             projectaction.append_selected_media_clips_into_timeline()
             return True
+    if action == "move_media":
+        gui.media_list_view.init_move()
 
     return False
     
@@ -760,7 +762,19 @@ def _handle_geometry_editor_keys(event):
 def _handle_effects_editor_keys(event):
     action = _get_shortcut_action(event)
     focus_editor = _get_focus_keyframe_editor(clipeffectseditor.keyframe_editor_widgets)
+
+                        
     if focus_editor != None:
+        if focus_editor.get_focus_child() != None:
+            if focus_editor.__class__ == keyframeeditor.FilterRectGeometryEditor or \
+                focus_editor.__class__ == keyframeeditor.FilterRotatingGeometryEditor or \
+                focus_editor.__class__ == keyframeeditor.GeometryNoKeyframes:
+                if ((event.keyval == Gdk.KEY_Left) 
+                    or (event.keyval == Gdk.KEY_Right)
+                    or (event.keyval == Gdk.KEY_Up)
+                    or (event.keyval == Gdk.KEY_Down)):
+                    focus_editor.arrow_edit(event.keyval, (event.get_state() & Gdk.ModifierType.CONTROL_MASK), (event.get_state() & Gdk.ModifierType.SHIFT_MASK))
+                    return True
         if action == 'play':
             targetactions.play()
             return True
