@@ -19,7 +19,7 @@
 """
 
 """
-Module contains GUI widgets used edit geometries on canvas with a mouse.
+Module contains GUI widgets used to edit geometries on canvas with a mouse.
 """
 
 import copy
@@ -276,6 +276,8 @@ class AbstractEditCanvas:
         self.source_height = -1 # unscaled source image height, set later
         
         self.coords = None # Calculated later when we have allocation available
+
+        self.active = True # used to disable if needed.
         
     def init_editor(self, source_width, source_height, y_fract):
         self.source_width = source_width 
@@ -364,6 +366,7 @@ class AbstractEditCanvas:
             # keyframe frame 0 cannot be removed
             return
         self.keyframes.pop(keyframe_index)
+        self._update_shape()
 
     def _frame_has_keyframe(self, frame):
         for i in range(0, len(self.keyframes)):
@@ -421,6 +424,9 @@ class AbstractEditCanvas:
         """
         Mouse button callback
         """
+        if self.active == False:
+            return
+
         self.current_mouse_hit = self._check_shape_hit(event.x, event.y)
         if self.current_mouse_hit == NO_HIT:
             return
@@ -443,6 +449,9 @@ class AbstractEditCanvas:
         """
         Mouse move callback
         """
+        if self.active == False:
+            return
+            
         if self.current_mouse_hit == NO_HIT:
             return
         
@@ -467,6 +476,9 @@ class AbstractEditCanvas:
         print("_shape__motion_notify_event not impl")
 
     def _release_event(self, event):
+        if self.active == False:
+            return
+
         global _shift_down 
         _shift_down = None
         
@@ -540,6 +552,11 @@ class AbstractEditCanvas:
         
         self._draw_edit_shape(cr, allocation)
 
+        if self.active == False:
+            cr.set_source_rgba(0.75, 0.75, 0.77, 0.65)
+            cr.rectangle(0, 0, w, h)
+            cr.fill()
+    
     def _draw_edge(self, cr, rect):
         cr.set_line_width(1.0)
         cr.set_source_rgb(0, 0, 0)
