@@ -104,6 +104,7 @@ force_proxy = False
 # This is needed to pass only one event for double click, double init for monitor click possibly somewhat unstable
 _media_panel_double_click_counter = 0
 
+_popover_media_file = None
 
 #--------------------------------------- worker threads
 class LoadThread(threading.Thread):
@@ -954,6 +955,8 @@ def _hamburger_menu_item_selected(action, variant, msg):
         append_selected_media_clips_into_timeline()
     elif msg == "reverse order":
         reverse_current_bin_media_order()
+    elif msg == "move to clicked":
+        gui.media_list_view.init_move()
     elif msg == "set bin default":
         current_default_length = PROJECT().get_current_bin_graphics_default_length()
         dialogs.set_bin_grfx_default_length_dialog( current_bin(),
@@ -1344,38 +1347,22 @@ def _display_file_info(media_file):
     dialogs.file_properties_dialog((media_file, img, size, length, vcodec, acodec, channels, frequency, fps, match_profile_name, matches_project_profile))
 
 def remove_unused_media():
-    unused = unused_media()
+    unused = PEOJECT().get_unused_media()
     # It is most convenient to do remove via gui object
     gui.media_list_view.select_media_file_list(unused)
     delete_media_files()
 
-def unused_media():
-    # Create path -> media item dict
-    path_to_media_object = {}
-    for key, media_item in list(PROJECT().media_files.items()):
-        if hasattr(media_item, "path") and media_item.path != "" and media_item.path != None:
-            path_to_media_object[media_item.path] = media_item
-    
-    # Remove all items from created dict that have a clip with same path on any of the sequences
-    for seq in PROJECT().sequences:
-        for track in seq.tracks:
-            for clip in track.clips:
-                try:
-                    path_to_media_object.pop(clip.path)
-                except:
-                    pass
-    
-    # Create a list of unused media objects
-    unused = []
-    for path, media_item in list(path_to_media_object.items()):
-        unused.append(media_item)
-    return unused
-
 def media_filtering_select_pressed(launcher, widget, event):
     guipopover.file_filter_popover_show(launcher, widget,  _media_filtering_selector_item_activated)
 
 def _media_filtering_selector_item_activated(action, new_value_variant):
-    index = int( new_value_variant.get_string())
+    try:
+        index = int( new_value_variant.get_string())
+    except:
+        # This is ratings selection
+        _ratings_filtering_item_activated(action, new_value_variant)
+        return
+
     gui.media_view_filter_selector.set_pixbuf(index)
     
     # Const values at appconst,py correspond with indexes here.
@@ -1384,7 +1371,21 @@ def _media_filtering_selector_item_activated(action, new_value_variant):
 
     action.set_state(new_value_variant)
     guipopover._file_filter_popover.hide()
-    
+
+def _ratings_filtering_item_activated(action, new_value_variant):
+    if new_value_variant.get_string() == "hide_bad":
+        editorstate.media_view_ratings_filter = appconsts.MEDIA_RATINGS_HIDE_BAD
+    elif new_value_variant.get_string() == "show_favorites":
+        editorstate.media_view_ratings_filter = appconsts.MEDIA_RATINGS_SHOW_FAVORITES
+    else:
+        editorstate.media_view_ratings_filter = appconsts.MEDIA_RATINGS_SHOW_ALL
+
+    gui.media_list_view.fill_data_model()
+
+    action.set_state(new_value_variant)
+    guipopover._file_filter_popover.hide()
+    gui.editor_window.bin_info.display_bin_info() 
+
 def columns_count_launch_pressed(launcher, widget, event):
     guipopover.columns_count_popupover_show(launcher, widget, _columns_count_item_selected)
     
@@ -2236,10 +2237,14 @@ def do_compositing_mode_change(new_compositing_mode):
 
 # --------------------------------------------------------- pop-up menus
 def media_file_popover_mouse_right_pressed(widget, media_file, event):
-    guipopover.media_file_popover_show(media_file, widget, event.x, event.y, media_file_menu_item_selected)
+    global _popover_media_file # we need this for media_file_menu_rating_item_selected()
+    _popover_media_file = media_file 
+    guipopover.media_file_popover_show(media_file, widget, event.x, event.y, media_file_menu_item_selected, media_file_menu_rating_item_selected)
     
 def media_file_menu_item_selected(action, variant, data):
-    item_id, media_file = data
+    item_id, unused = data
+    global _popover_media_file
+    media_file = _popover_media_file
     if item_id == "File Properties":
         _display_file_info(media_file)
     if item_id == "Open in Clip Monitor":
@@ -2262,7 +2267,21 @@ def media_file_menu_item_selected(action, variant, data):
         media_file.create_icon()
     if item_id == "Replace":
         replace_media_file(media_file)
-        
+
+def media_file_menu_rating_item_selected(action, variant):
+    global _popover_media_file
+    if variant.get_string() == "unrated":
+        _popover_media_file.rating = appconsts.MEDIA_FILE_UNRATED
+    elif variant.get_string() == "favorite":
+        _popover_media_file.rating = appconsts.MEDIA_FILE_FAVORITE
+    else:
+        _popover_media_file.rating = appconsts.MEDIA_FILE_BAD
+
+    action.set_state(variant)
+    editorpersistance.save()
+    guipopover._media_file_popover.hide()
+    gui.media_list_view.widget.queue_draw()
+
 def _select_treeview_on_pos_and_return_row_and_column_title(event, treeview):
     selection = treeview.get_selection()
     path_pos_tuple = treeview.get_path_at_pos(int(event.x), int(event.y))
