@@ -112,8 +112,6 @@ _hamburger_popover = None
 
 #-------------------------------------------------- launch and inits
 def launch_scripttool(launch_data=None):
-    gui.save_current_colors()
-
     # no args yet
     args = ["profile_name:" + editorstate.PROJECT().profile.description()]
         
@@ -196,7 +194,6 @@ class ScriptToolApplication(Gtk.Application):
 
         # Themes
         gui.apply_theme(editorpersistance.prefs.theme)
-        gui.load_current_colors()
 
         # Get launch profile and init player and display GUI params for it. 
         global _current_profile_name
@@ -520,7 +517,7 @@ def render_preview_frame():
     _mark_out = -1
     _window.update_marks_display()
     
-    fctx = fluxity.render_preview_frame(script, _last_save_path, frame, get_session_folder(), _profile_file_path)
+    fctx = fluxity.render_preview_frame(script, _last_save_path, frame, 200, get_session_folder(), _profile_file_path)
     _window.pos_bar.preview_range = None # frame or black for fail, no range anyway
         
     if fctx.error == None:
@@ -720,8 +717,6 @@ class ScriptToolWindow(Gtk.Window):
         # -------------------------------------------------------------------- RIGHT SIDE: MONITOR, CONTROLS, ENCODING 
         black_box = Gtk.EventBox()
         black_box.add(Gtk.Label())
-        bg_color = Gdk.Color(red=0.0, green=0.0, blue=0.0)
-        black_box.modify_bg(Gtk.StateType.NORMAL, bg_color)
         self.monitor = black_box  # This could be any GTK+ widget (that is not "windowless"), only its XWindow draw rect 
                                   # is used to position and scale SDL overlay that actually displays video.
         self.monitor.set_size_request(MONITOR_WIDTH, MONITOR_HEIGHT)
@@ -1286,7 +1281,10 @@ class FluxityRangeRenderer(threading.Thread):
         self.in_frame = in_frame
         out_frame = _mark_out
         self.out_frame = out_frame  
-    
+        
+        # TODO: Make user settable
+        generator_length = 200
+            
         parent_folder = userfolders.get_temp_render_dir()
     
         ccrutils.init_session_folders(parent_folder, SCRIPT_TOOL_SESSION_ID)
@@ -1305,7 +1303,7 @@ class FluxityRangeRenderer(threading.Thread):
             GLib.idle_add(_show_error, err_msg)
             return
 
-        _launch_headless_render(SCRIPT_TOOL_SESSION_ID, tmp_script_file, edit_data, frames_folder, in_frame, out_frame + 1)
+        _launch_headless_render(SCRIPT_TOOL_SESSION_ID, tmp_script_file, edit_data, frames_folder, generator_length, in_frame, out_frame + 1)
 
         GLib.timeout_add(200, _preview_render_update, self)
 
@@ -1416,6 +1414,9 @@ class FluxityPluginRenderer(threading.Thread):
         self.in_frame = in_frame
         self.out_frame = out_frame
         
+        # TODO: Make user settable
+        generator_length = 200
+        
         # not used !!!
         frame_name = _window.frame_name.get_text()
 
@@ -1446,7 +1447,7 @@ class FluxityPluginRenderer(threading.Thread):
             return
 
         self.frames_render_in_prgress = True
-        _launch_headless_render(SCRIPT_TOOL_SESSION_ID, tmp_script_file, edit_data, frames_folder, in_frame, out_frame + 1)
+        _launch_headless_render(SCRIPT_TOOL_SESSION_ID, tmp_script_file, edit_data, frames_folder, generator_length, in_frame, out_frame + 1)
         
         self.render_start_time = datetime.datetime.now()
         GLib.timeout_add(150, _output_render_update, self)
@@ -1592,7 +1593,7 @@ def _output_render_update(render_thread):
         _window.render_progress_bar.set_fraction(progress)
         return True # Function will be called again.
 
-def _launch_headless_render(session_id, script_path, edit_data, frames_folder, range_in, range_out):
+def _launch_headless_render(session_id, script_path, edit_data, frames_folder, generator_length, range_in, range_out):
 
     parent_folder = userfolders.get_temp_render_dir()
     
@@ -1618,6 +1619,7 @@ def _launch_headless_render(session_id, script_path, edit_data, frames_folder, r
     args = ("session_id:" + session_id,
             "parent_folder:" + parent_folder,
             "script:" + script_path,
+            "generator_length:" + str(generator_length),
             "range_in:" + str(range_in),
             "range_out:"+ str(range_out),
             "profile_desc:" + _current_profile_name.replace(" ", "_"))  # Here we have our own string space handling, maybe change later..
